Command Line Interface#

This page lists all available terminal commands and subcommands of irdl.

irdl#

Handle version flag.

Usage:

$ irdl [OPTIONS] COMMAND [ARGS]...

Options:

  • --version: Show version and exit.

  • --install-completion: Install completion for the current shell.

  • --show-completion: Show completion for the current shell, to copy it or customize the installation.

  • --help: Show this message and exit.

Commands:

  • list: List all available datasets.

  • cache: Manage cache directory.

  • get: Download datasets.

irdl list#

List all available datasets.

Usage:

$ irdl list [OPTIONS]

Options:

  • --help: Show this message and exit.

irdl cache#

Manage cache directory.

Usage:

$ irdl cache [OPTIONS] COMMAND [ARGS]...

Options:

  • --cache-dir PATH: Custom cache directory path.

  • --help: Show this message and exit.

Commands:

  • size: Show cache directory size.

  • dir: Show cache directory path.

  • clean: Wipe cache directory.

  • prune: Remove unreachable cache items for known…

irdl cache size#

Show cache directory size.

Usage:

$ irdl cache size [OPTIONS]

Options:

  • -H, --human-readable: Format size with binary units.

  • --help: Show this message and exit.

irdl cache dir#

Show cache directory path.

Usage:

$ irdl cache dir [OPTIONS]

Options:

  • --help: Show this message and exit.

irdl cache clean#

Wipe cache directory.

Usage:

$ irdl cache clean [OPTIONS]

Options:

  • --help: Show this message and exit.

irdl cache prune#

Remove unreachable cache items for known datasets.

Usage:

$ irdl cache prune [OPTIONS]

Options:

  • --help: Show this message and exit.

irdl get#

Download datasets.

Usage:

$ irdl get [OPTIONS] COMMAND [ARGS]...

Options:

  • --help: Show this message and exit.

Commands:

  • bras-rs8: Download the BRAS RS8 dataset from…

  • fabian: Download and extract the FABIAN HRTF…

  • hutubs: Download the HUTUBS HRTF database from…

  • miracle: Download the MIRACLE database from…

  • sriracha: Download and merge the SRIRACHA database…

irdl get bras-rs8#

Download the BRAS RS8 dataset from DepositOnce.

DOI: https://doi.org/10.14279/depositonce-25649

Usage:

$ irdl get bras-rs8 [OPTIONS]

Options:

  • --scene TEXT: Scene identifier to download. One of: ‘01a’, ‘01b’, ‘01c’, ‘02’, ‘03a’, ‘03b’, ‘03c’, ‘03d’, ‘03e’. Default is ‘01a’. [default: 01a]

  • --cache-dir TEXT: Cache directory for downloads. Defaults is the OS user cache directory. This default can be overridden by setting IRDL_CACHE_DIR environment variable.

  • --export-dir TEXT: Directory for final output. If specified, the data will be exported to <export_dir/BRAS-RS8/>. Else, it remains in <cache_dir/output/>.

  • --output-format TEXT: Output format: ‘pyfar’, ‘numpy’, ‘hdf5’, ‘sofa’, or ‘raw’. [default: pyfar]

  • --help: Show this message and exit.

irdl get fabian#

Download and extract the FABIAN HRTF database from DepositOnce.

DOI: https://doi.org/10.14279/depositonce-5718.5

Usage:

$ irdl get fabian [OPTIONS]

Options:

  • --kind TEXT: Type of HRTF to download. Either ‘measured’ or ‘simulated’. Default is ‘measured’. [default: measured]

  • --hato INTEGER: Head-above-torso-rotation of HRTFs in degrees. One of: 0, 10, 20, 30, 40, 50, 310, 320, 330, 340, 350. Default is 0. [default: 0]

  • --cache-dir TEXT: Cache directory for downloads. Defaults is the OS user cache directory. This default can be overridden by setting IRDL_CACHE_DIR environment variable.

  • --export-dir TEXT: Directory for final output. If specified, the data will be exported to <export_dir/FABIAN/>. Else, it remains in <cache_dir/output/>.

  • --output-format TEXT: Output format: ‘pyfar’, ‘numpy’, ‘hdf5’, ‘sofa’, or ‘raw’. [default: pyfar]

  • --help: Show this message and exit.

irdl get hutubs#

Download the HUTUBS HRTF database from DepositOnce.

DOI: https://doi.org/10.14279/depositonce-8487

Usage:

$ irdl get hutubs [OPTIONS]

Options:

  • --subject INTEGER: Subject identifier. Must be an integer in the range 1 to 96. Default is 1. [default: 1]

  • --kind TEXT: HUTUBS HRIR variant. Either ‘measured’ or ‘simulated’. Default is ‘measured’. [default: measured]

  • --cache-dir TEXT: Cache directory for downloads. Defaults is the OS user cache directory. This default can be overridden by setting IRDL_CACHE_DIR environment variable.

  • --export-dir TEXT: Directory for final output. If specified, the data will be exported to <export_dir/HUTUBS/>. Else, it remains in <cache_dir/output/>.

  • --output-format TEXT: Output format: ‘pyfar’, ‘numpy’, ‘hdf5’, ‘sofa’, or ‘raw’. [default: pyfar]

  • --help: Show this message and exit.

irdl get miracle#

Download the MIRACLE database from DepositOnce.

DOI: https://doi.org/10.14279/depositonce-20837

Usage:

$ irdl get miracle [OPTIONS]

Options:

  • --scenario TEXT: Scenario to download. One of ‘A1’, ‘A2’, ‘D1’, ‘R2’. [default: A1]

  • --dataset-split TEXT: Artificial dataset split. One of ‘C1’, ‘C2’, ‘C3’, ‘C4’ or None. Dense scenarios (D1) cannot be split.

  • --cache-dir TEXT: Cache directory for downloads. Defaults is the OS user cache directory. This default can be overridden by setting IRDL_CACHE_DIR environment variable.

  • --export-dir TEXT: Directory for final output. If specified, the data will be exported to <export_dir/MIRACLE/>. Else, it remains in <cache_dir/output/>.

  • --output-format TEXT: Output format: ‘pyfar’, ‘numpy’, ‘hdf5’, ‘sofa’, or ‘raw’. [default: pyfar]

  • --help: Show this message and exit.

irdl get sriracha#

Download and merge the SRIRACHA database from DepositOnce.

DOI: https://doi.org/10.14279/depositonce-23943

Usage:

$ irdl get sriracha [OPTIONS]

Options:

  • --scenario TEXT: Scenario to download. One of ‘SR1’, ‘SRA1’, ‘SR1-D’, ‘SRA1-D’, ‘SR2’, ‘SRA2’, ‘SR2-D’, ‘SRA2-D’. Default is ‘SR1-D’. [default: SR1-D]

  • --dataset-split TEXT: Optional dataset split for full-plane scenarios. One of ‘C1’, ‘C2’, ‘C3’, ‘C4’ or None. Dense scenarios (ending in ‘-D’) do not have splits. Default is None.

  • --cache-dir TEXT: Cache directory for downloads. Defaults is the OS user cache directory. This default can be overridden by setting IRDL_CACHE_DIR environment variable.

  • --export-dir TEXT: Directory for final output. If specified, the data will be exported to <export_dir/SRIRACHA/>. Else, it remains in <cache_dir/output/>.

  • --output-format TEXT: Output format: ‘pyfar’, ‘numpy’, ‘hdf5’, ‘sofa’, or ‘raw’. [default: pyfar]

  • --help: Show this message and exit.