Python API#

The public Python API is centered on concrete Dataset classes and a shared retrieval flow.

Dataset modules#

akt

Datasets from the Audio Communications Group of TU Berlin, Berlin, Germany.

base

Base Dataset class and conversion utilities for IRDL.

ista

Datasets from the Department of Engineering Acoustics, TU Berlin, Berlin Germany.

sofa

Impulse response datasets in SOFA format.

Internal modules#

cli

Automagic generation of a Typer script for all dataset downloads.

downloader

Implements download and post-processing based on pooch.

logging

Logging configuration for IRDL.

repositories

Implements custom data repositories and patches the pooch DOI resolver.

utils

Utility functions for IRDL.