Python API#
The public Python API is centered on concrete Dataset classes and a shared retrieval flow.
Dataset modules#
Internal modules#
Automagic generation of a Typer script for all dataset downloads. |
|
Implements download and post-processing based on pooch. |
|
Logging configuration for IRDL. |
|
Implements custom data repositories and patches the pooch DOI resolver. |
|
Utility functions for IRDL. |